Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/rgb_display_simpletest.py
    :caption: examples/rgb_display_simpletest.py
    :linenos:

.. literalinclude:: ../examples/rgb_display_ili9341test.py
    :caption: examples/rgb_display_ili9341test.py
    :linenos:
